"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from que_media.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CawgVerifyDtoTypedDict(TypedDict):
    r"""Options controlling CAWG identity validation behavior during verification."""

    validate_: NotRequired[bool]
    r"""Whether to run CAWG identity validation."""
    require_valid_identity: NotRequired[bool]
    r"""Whether to fail verification if CAWG identity is missing/invalid."""


class CawgVerifyDto(BaseModel):
    r"""Options controlling CAWG identity validation behavior during verification."""

    validate_: Annotated[Optional[bool], pydantic.Field(alias="validate")] = True
    r"""Whether to run CAWG identity validation."""

    require_valid_identity: Optional[bool] = False
    r"""Whether to fail verification if CAWG identity is missing/invalid."""
