"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from que_media.types import BaseModel
from typing_extensions import TypedDict


class PresignedURLTypedDict(TypedDict):
    r"""An asset accessible via HTTP/HTTPS URL. The URL must be enabled via the ALLOW_URL_ASSETS environment variable. The service will stream the file to temporary storage during processing."""

    url: str
    r"""The HTTP/HTTPS URL of the asset. Must be publicly accessible."""


class PresignedURL(BaseModel):
    r"""An asset accessible via HTTP/HTTPS URL. The URL must be enabled via the ALLOW_URL_ASSETS environment variable. The service will stream the file to temporary storage during processing."""

    url: str
    r"""The HTTP/HTTPS URL of the asset. Must be publicly accessible."""
