"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from que_media.types import BaseModel
from typing_extensions import TypedDict


class S3TypedDict(TypedDict):
    r"""An asset located in an S3 bucket that the Que service has access to. The service will stream the file from S3 to temporary storage during processing."""

    bucket: str
    r"""The name of the S3 bucket."""
    key: str
    r"""The object key (path) within the S3 bucket."""


class S3(BaseModel):
    r"""An asset located in an S3 bucket that the Que service has access to. The service will stream the file from S3 to temporary storage during processing."""

    bucket: str
    r"""The name of the S3 bucket."""

    key: str
    r"""The object key (path) within the S3 bucket."""
