"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .trustlistresponse import TrustListResponse, TrustListResponseTypedDict
from que_media.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class GetTrustListResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: TrustListResponseTypedDict


class GetTrustListResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: TrustListResponse
