"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .signresponse import SignResponse, SignResponseTypedDict
from que_media.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class SignAssetResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: SignResponseTypedDict


class SignAssetResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: SignResponse
