"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .presignedurl import PresignedURL, PresignedURLTypedDict
from .s3 import S3, S3TypedDict
from typing import Union
from typing_extensions import TypeAliasType


AssetRefDtoTypedDict = TypeAliasType(
    "AssetRefDtoTypedDict", Union[PresignedURLTypedDict, S3TypedDict]
)
r"""A reference to a digital asset, either stored in S3 or accessible via URL. Files are streamed efficiently to temporary storage during processing to minimize memory usage."""


AssetRefDto = TypeAliasType("AssetRefDto", Union[PresignedURL, S3])
r"""A reference to a digital asset, either stored in S3 or accessible via URL. Files are streamed efficiently to temporary storage during processing to minimize memory usage."""
