"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from que_media.types import BaseModel
from typing_extensions import TypedDict


class HealthzResponseTypedDict(TypedDict):
    status: str
    message: str
    timestamp: int
    r"""The Unix epoch timestamp when the health check was performed."""


class HealthzResponse(BaseModel):
    status: str

    message: str

    timestamp: int
    r"""The Unix epoch timestamp when the health check was performed."""
