"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from que_media.types import BaseModel
from typing_extensions import TypedDict


class VerifyResponseTypedDict(TypedDict):
    r"""The result of a C2PA manifest verification operation."""

    report: str
    r"""JSON string containing the verification report from the C2PA engine. The structure varies based on the verification mode requested."""


class VerifyResponse(BaseModel):
    r"""The result of a C2PA manifest verification operation."""

    report: str
    r"""JSON string containing the verification report from the C2PA engine. The structure varies based on the verification mode requested."""
